@@ -1654,7 +1654,7 @@ int do_send (int sk, const void *data, size_t len, const sockaddr_any *addr) {
 	if (res < 0) {
 	    if (errno == ENOBUFS || errno == EAGAIN)
 		    return res;
-	    if (errno == EMSGSIZE)
+	    if (errno == EMSGSIZE || errno == EHOSTUNREACH)
 		    return 0;	/*  recverr will say more...  */
 	    error ("send");	/*  not recoverable   */
 	}
